# Introduction #
In 2004, the Alfred P. Sloan Foundation launched a program focusing on the "Microbiology of the Built Environment", sometimes known as "MoBE".  The aims of this program were to catalyze research on microbes and microbial communities in human built environments, such as homes, vehicles, and water systems; and to develop the topic into a whole field of inquiry.  Prior to 2004, many new developments (e.g., major advances in DNA sequencing technology) had catalyzed innovation in studies of microbes found in other environments (e.g., those living in and on humans and other animals, those found in the soil, those found in the oceans), but these innovations had not spread rapidly enough to studies of the microbes in the built environment. Similarly, many developments had occurred in studies of the built environment (e.g., the spread of low cost sensor systems), but focus had not yet been placed on the living, microbial components of built environments. This is not to say there had been no studies on the MoBE topic prior to 2004, but rather that the pace of advances in the area were modest at best compared to advances in other areas of microbiology and built environment studies. The MoBE area was founded on the belief that institutionally supported, integrated, trans-disciplanary scientific inquiry could address these shortfalls and lead to major benefits in areas such as indoor health, disease transmission, biodefense, forensics, and energy efficiency. 

The Sloan Foundation's program ultimately lasted 15 years and invested more than $50 million on work in the MoBE field. A key goal of this program was to bring together the highly disparate fields of microbiology (especially the area focused on studies of entire ecosystems of microbes) and building science (e.g. with a focus on building, maintaining, regulating, and studying built environments) with their different approaches, cultures, incentives, and rewards. Grants were given to many projects and a diverse collection of people covering many fields including microbiology, architecture, building science, software development, and meeting organization (a list of all grants from the program can be found at <https://sloan.org/grants-database?setsubprogram=2>). The products of these grants included a diverse collection of  programs and projects, dozens of new collaborations, many novel and sometimes large data sets on various MoBE topics, new software and tools for MoBE studies, and hundreds of scholarly publications. 

Recent reviews of the state of the field (e.g. \cite{Gilbert2018}\cite{2017}) have qualitatively highlighted the success of this program. In this paper we report a quantitative assessment of the Sloan MoBE program and the MoBE field using a network analysis of scholarly literature.  Specifically, the aim of this study was to compare the community of researchers funded by the Sloan Foundation's MoBE program to their scientific peers. If the Sloan Foundation's program was successful at cultivating a new research community around MoBE topics, we hypothesized that we would see the evolution of an increasingly dense and more tightly connected network over the duration of the funding program.  

Programs explicitly dedicated to funding interdisciplinary research may have an important role to play in the development of new research communities.  \cite{Bromham_2016} finds that interdisciplinary research proposals are less likely to be funded by the Australian Research Council’s Discovery Programme, which is designed to fund basic research across the disciplines but is not explicitly interdisciplinary.  This indicates an incentive for researchers to propose — and then conduct — disciplinary research, which is more likely to build on established research communities.  By contrast, \cite{simmonsforthcoming} finds evidence of both novel collaborations as well as cross-disciplinary citations and publications for researchers funded by the US National Robotics Initiative program, which is explicitly interdisciplinary.  

\cite{Bettencourt_2009} proposes that coauthor networks can be used to examine the emergence of Kuhnian "normal science" \cite{kuhn1970}.  Specifically, they relate the formation of a giant component — in which a single connected component of the network contains a supermajority of authors — to the formation of the kind of research community Kuhn described.  \cite{Bettencourt_2009} focuses on three topological statistics for coauthor networks:  (1) the diameter (average shortest path length between pairs of nodes) of the largest component, (2) the fraction of edges in the largest component, and (3) "densification," the exponent of a power law model relating edge and node counts across time for a given dynamic network.  While diameter and edge fraction are dynamic, calculated at each time step (e.g., annually) as the coauthor network changes, densification is a summary across time.  \cite{Citron_2018} uses topic modeling to subdivide papers from the arXiv, the physics repository, into various subfields, then applies the approach of \cite{Bettencourt_2009} to examine the dynamics of coauthor networks in each subfield.  Following \cite{Bettencourt_2009}, \cite{Citron_2018} also uses the diameter of the largest component as a key statistic, but also examines the fraction of nodes, rather than edges, in the largest component.  

As \cite{Bettencourt_2009} acknowledges, Kuhn's notion of a paradigm and normal scientific research is controversial.  In addition, network topology alone cannot provide insight into the normative aspects of a Kuhnian paradigm.  That is, in Kuhn's view, a paradigm provides a rules and standards for good scientific research.  The term paradigm comes from linguistics, in which a paradigm characterizes rules and standards for a specific construction.  For example, "amo, amas, amat, amamus, amatis, amant" is a paradigm for the first conjugation of Latin verbs.  Similarly, the paradigms for a normal science (e.g., protocols for experimental design and statistical analysis) provide shared rules and standards for good research — at least for the research community operating under the paradigm.  The fact that a network of researchers are working with each other does not tell us whether they have this kind of shared normative framework.  

However, the fact that a network of researchers are working with each other (or not) does provide insight into the structural possibilities for the circulation of ideas and information among researchers.  Information flow within and across the boundaries of scientific communities has long been a major topic in science and technology studies (STS) and philosophy of science \cite{Star_1989,expertise2010,Rosenstock_2017}.  Increased information flow is also often a key goal of research funding programs, especially information flow across disciplinary boundaries \cite{Holbrook_2012}.  Insofar as a scientific community is defined in terms of information flow, a transition from a disconnected or loosely-connected collaboration network to a highly-connected one does provide evidence for the formation of a scientific community. 

\cite{Koseoglu_2016} moves from coauthor networks to institutional collaboration networks (if X and Y are coauthors, then their respective institutions are collaborators) to examine the development of the field of strategic management.  \cite{Koseoglu_2016} calculates several dynamic network statistics for institutional networks, including average clustering, diameter, "connectedness" and "fragmentation" (which unfortunately are not defined, and have various incompatible definitions in the network analysis literature), and the number and fraction of nodes in the largest component.  

\cite{Kastrin_2018} examines the role of funded researchers ("PIs") in the collaboration network in Slovenia from 1970-2016.  Part of their analysis focuses on the relationship among several statistics over overlapping time periods, including the fraction of nodes in the giant component, the mean fraction of each node's neighbors who are PIs, the number of connected components when PIs are removed from the giant component, and the relative size of the largest component when PIs are removed.  

All of these studies use dynamic analysis of coauthor networks to examine development and change in research communities over time.  However, none of these studies is designed to examine the effect of a particular funding program on the research community, and only \cite{Kastrin_2018} situates the group of researchers of interest ("PIs" or funded researchers) in the context of their peers (i.e., authors who were not funded).  

In contrast, \cite{Ta_k_n_2015} uses coauthor and institutional collaboration networks, among other bibliometric methods, to examine the impact of a US National Aeronautics and Space Administration (NASA) program focused on astrobiology; while \cite{Zoss_2011} uses a coauthor network, again among other methods, to study the early impacts of the US National Science Foundation (NSF) Science of Science Policy (SciSIP) program.  Because these are early assessments of their respective funding programs, both of these studies use static rather than dynamic collaboration networks.  

\cite{Fujita_2017} and \cite{Liang_2018} use dynamic network methods to analyze individual-level funding program impacts.  \cite{Fujita_2017} compares participants in two fellowship programs, funded by Japan Science and Technology Agency and Japan Society for the Promotion of Science, to their peers in a large literature database, focusing on individual betweeness centrality over time.  \cite{Liang_2018} tests several hypotheses concerning the relationship between local topological features of the network (e.g., the size of a researcher's neighborhood) and patent applications under a Chinese program to fund photovoltaic research.  

Of these four program assessment studies, only \cite{Fujita_2017} incorporates a comparison group of researchers.  

In the present study, we use the theoretically-informed approach developed in \cite{Bettencourt_2009} and \cite{Citron_2018} to examine the community-level impact of a specific funding program, namely, the MoBE program.  By comparing MoBE-funded researchers to their peers, and incorporating robustness checks for the way peers are identified, we can have more confidence in the interpretation of our results as identifying causal effects of the MoBE program.  In addition, by deploying a wider variety of network statistics, we identify changes in the coauthor networks that would be missed by the smaller set of statistics used in \cite{Bettencourt_2009} and \cite{Citron_2018}.  

Compared to the literature reviewed above, our study is distinctive for using network analysis methods and a comparison group of researchers to analyze the community-level impacts of a particular research funding program.  To be clear, we make no claims here about the impacts of research funding programs more generally, but we do think that the MoBE program is an interesting case of an explicit attempt to create an interdisciplinary, multi-institution research community.  Insofar as we find that the MoBE program was successful in this attempt, future research might identify specific features of the program that contributed to this success and could be generalized to other such programs.  