## Network Analysis ##

The analysis dataset of 85,306 papers was used as the basis for constructing time-indexed collaboration networks. Each author forms a node (distinguished by author ID); edges correspond to papers published in a given year, so that two authors are connected by an edge for a given year if they coauthored at least one paper published in that year. All collaboration authors had at least one edge; 72 comparison authors did not have at least one edge (i.e., at least one paper coauthored with another author in the dataset), and were dropped from the network analysis (remaining comparison n = 698). Authors who collaborated on multiple papers in a given year were connected with multiple edges, except when calculating density (see below).

After constructing the combined (collaboration + comparison) network, separate cumulative-annual networks were constructed for each set of authors. For example, two authors would be connected in the 2011 network if and only if (1) they were in the same author set and (2) they had coauthored at least one publication between 1999 and 2011 inclusive. Cumulative networks were used to reduce noise in the most recent years, due to incomplete data for 2018 and as the Sloan Foundation's funding program was starting to wind down. Analyzing separate cumulative networks allows the examination of the development of research communities through time and between the author sets. 

For network analysis, we extended the approach developed by \cite{Bettencourt_2009} and \cite{Citron_2018}.  Specifically, both of these studies proposed that community formation can be measured in terms of giant component coverage and mean distance or shortest path length: increasing coverage combined with decreased distance indicates community consolidation.  Neither \cite{Bettencourt_2009} nor \cite{Citron_2018} used a control or comparison group (neither study aimed to to examine the impact of a specific funding program or other intervention).  In the study, we calculated a total of eight network topological statistics and directly compare the two author sets. Specifically, we calculated the number of authors, number of components, coverage of the giant component (as a fraction of authors included in the largest component), entropy (\(H\)) of the component size distribution, diameter, density (fraction of all possible edges actually realized), mean distance, and transitivity in each year.

Number of authors simply measures the total size of each network. Because these are cumulative networks, the number of authors necessarily increases. The number of components, coverage of the giant component, and entropy of the component distribution are measures of the large-scale structure of the network. More components indicate that the network is divided into subcommunities that do not interact (at least in terms of coauthoring papers); fewer components indicates consolidation of the research community.  Giant component coverage and entropy measure the relative sizes of these different components; higher giant component coverage and lower entropy indicate that more authors can be found in a single component, which in turn indicates research community consolidation.

Diameter, density, and mean distance can be interpreted as measures of the ability of information to flow through the network. Lower diameter, higher density, and lower mean distance indicate that it is easier for information to move between any two given researchers, as there are fewer intermediary coauthors and a higher probability of a direct connection. These therefore indicate research community consolidation.

Transitivity is an aggregate measure of the local-scale structure of the network. Low transitivity indicates that the network is comprised of loosely connected clusters; there is collaboration across groups of researchers, but it is relatively rare. High transitivity, by contrast, indicates that the network cannot be divided into distinguishable clusters. High transitivity therefore indicates research community consolidation.  

Two robustness checks were incorporated into our analysis.  First, to account for the possibility of data errors or missingness, perturbed networks were generated for each year by randomly switching the endpoints of 5% of edges.  Second, the construction of the comparison set is likely to exclude students, postdoctoral researchers, and other early-career researchers.  Insofar as these types of authors are included in the collaboration set, the collaboration network may appear to be more well-connected than the comparison set.  To account for this possibility, we construct and analyze filtered versions of the annual cumulative networks.  Authors are included in the filtered versions only if they have 50 or more papers total in the analysis analysis dataset.

Acknowledgment sections and other sources of funding information are not included in the metadata retrieved for this analysis.  We are therefore unable to identify funding sources except for MoBE-funded papers, for which we have our own metadata.  The comparison method is thus designed to test only whether or not the removal of MoBE-funded research produces a response effect in the shape of the overall discursive space.  It does not consider independent relationships between MoBE and other sources nor relationships between non-MoBE sources.  An underlying assumption of the analysis is, therefore, that the rates of impact from other sources of research funding are constant and that there is no underlying relationship between MoBE funding and other funding sources such that the removal of MoBE funding results in uneven removal of another source(s) of funding. Examining these relationships is potential direction for future study. 

All data collection and analysis was carried out in R \cite{team2018}.  Complete data collection and analysis code, as well as the list of MoBE-funded publications, is available at <https://doi.org/10.5281/zenodo.2548839>.  